---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2010-07-02;104
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20100707&codiceRedaz=010G0127&dataVigenza=20251104
dataGU: 20100707
codiceRedaz: 010G0127
dataVigenza: 20251104
---

# Attuazione dell'articolo 44 della legge 18 giugno 2009, n. 69, recante delega al governo per il riordino del processo amministrativo. (10G0127)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87 e 117, secondo comma, lettera l), della Costituzione;

Vista la legge 18 giugno 2009, n. 69, ed in particolare l'articolo 44, recante delega al Governo per il riassetto della disciplina del processo amministrativo, nel quale, al comma 4, e' previsto che il Governo puo' avvalersi della facolta' di cui all'articolo 14, numero 2), del testo unico sul Consiglio di Stato, di cui al regio decreto 26 giugno 1924, n. 1054;

Vista la nota in data 8 luglio 2009 con la quale il Governo, avvalendosi della facolta' di cui all'articolo 14, numero 2), del citato testo unico n. 1054 del 1924, ha commesso al Consiglio di Stato la formulazione del progetto del suddetto decreto legislativo;

Visto il decreto del Presidente del Consiglio di Stato in data 23 luglio 2009, con il quale la formulazione di detto progetto e' stata deferita ad una commissione speciale e ne e' stata stabilita la composizione;

Visto il progetto del decreto legislativo recante il «codice del processo amministrativo» e le relative norme di attuazione, transitorie, di coordinamento e di abrogazione, redatto da detta commissione speciale e trasmesso al Governo con nota del Presidente del Consiglio di Stato in data 10 febbraio 2010;

Vista la deliberazione preliminare del Consiglio dei Ministri, adottata nella riunione del 16 aprile 2010;

Acquisito il parere reso dalle competenti Commissioni parlamentari;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 24 giugno 2010;

Sulla proposta del Presidente del Consiglio dei Ministri;

Emana il seguente decreto legislativo:

## Art. 1. - Approvazione del codice e delle disposizioni connesse

1. E' approvato il codice del processo amministrativo di cui all'allegato 1 al presente decreto.

2. Sono altresi' approvate le norme di attuazione di cui all'allegato 2, le norme transitorie di cui all'allegato 3 e le norme di coordinamento e le abrogazioni di cui all'allegato 4.

## Art. 2. - Entrata in vigore

1. Il presente decreto entra in vigore il 16 settembre 2010.

